==> JOB-3.1.2.tar.gz: JOB-3.1.2/naming/test/TestBindContext.java <==
// **********************************************************************
//
// Copyright (c) 1999
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1999
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package test;

import org.omg.CORBA.*;
import org.omg.CosNaming.*;
import org.omg.CosNaming.NamingContextPackage.*;

class TestBindContext
{
    static void test(ORB orb, NamingContext root)
	throws UserException
    {
	TestObject test = new TestObject_impl();
	NameComponent[] name1, name2;
	NamingContext context;

	context = root.new_context();

	//
	// Test exceptions
	//

	try
	{
	    //
	    // Try to bind a context when an intermediate context
	    // doesn't exist
	    //
	    name1 = new NameComponent[2];
	    name1[0] = new NameComponent("bad", "node");
	    name1[1] = new NameComponent("my", "node");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.missing_node)
		throw new RuntimeException();
	}

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("object", "");
	root.bind(name1, test);

	try
	{
	    //
	    // Try to bind a context when an object is in the path
	    //
	    name2 = new NameComponent[2];
	    name2[0] = new NameComponent("object", "");
	    name2[1] = new NameComponent("my", "node");
	    root.bind_context(name2, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.not_context)
		throw new RuntimeException();
	}

	try
	{
	    //
	    // Try to bind a context using the name of an existing object
	    //
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	root.unbind(name1);

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("context", "");
	root.bind_context(name1, context);

	try
	{
	    //
	    // Try to bind an object using the name of an existing context
	    //
	    root.bind(name1, test);

	    // bind should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	root.unbind(name1);

	try
	{
	    //
	    // Try to bind a context with an invalid name
	    //
	    name1 = new NameComponent[0];
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(InvalidName ex)
	{
	    // expected
	}

	try
	{
	    //
	    // Try to bind a context with an invalid name
	    //
	    name1 = new NameComponent[1];
	    name1[0] = new NameComponent("", "");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(InvalidName ex)
	{
	    // expected
	}

	//
	// Bind an intermediate context for use in more tests
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("ctx", "");
	root.bind_context(name1, context);

	try
	{
	    //
	    // Try to bind a context when an intermediate context
	    // doesn't exist
	    //
	    name1 = new NameComponent[3];
	    name1[0] = new NameComponent("ctx", "");
	    name1[1] = new NameComponent("bad", "node");
	    name1[2] = new NameComponent("my", "node");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.missing_node)
		throw new RuntimeException();
	}

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("object", "");
	context.bind(name1, test);

	try
	{
	    //
	    // Try to bind a context when an object is in the path
	    //
	    name2 = new NameComponent[3];
	    name2[0] = new NameComponent("ctx", "");
	    name2[1] = new NameComponent("object", "");
	    name2[2] = new NameComponent("my", "node");
	    root.bind_context(name2, null);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.not_context)
		throw new RuntimeException();
	}

	try
	{
	    //
	    // Try to bind a context to an existing name
	    //
	    name2 = new NameComponent[2];
	    name2[0] = new NameComponent("ctx", "");
	    name2[1] = new NameComponent("object", "");
	    root.bind_context(name2, null);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	context.unbind(name1);

	//
	// Clean up context
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("ctx", "");
	root.unbind(name1);

	//
	// Test name equality to make sure kind is included in comparisons
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("context", "kind1");
	name2 = new NameComponent[1];
	name2[0] = new NameComponent("context", "kind2");
	root.bind_context(name1, null);
	root.bind_context(name2, null);
	root.unbind(name1);
	root.unbind(name2);

	//
	// Bind a nil context
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("nil_ctx", "");
	root.bind_context(name1, null);

	try
	{
	    //
	    // Try to bind a context through a nil context
	    //
	    name2 = new NameComponent[2];
	    name2[0] = new NameComponent("nil_ctx", "");
	    name2[1] = new NameComponent("object", "");
	    root.bind_context(name2, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(CannotProceed ex)
	{
	    // expected
	}

	root.unbind(name1);
	context.destroy();
    }
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/naming/test/TestBindContext.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package test;

import org.omg.CORBA.*;
import org.omg.CosNaming.*;
import org.omg.CosNaming.NamingContextPackage.*;

class TestBindContext
{
    static void test(ORB orb, NamingContext root)
	throws UserException
    {
	TestObject test = new TestObject_impl();
	NameComponent[] name1, name2;
	NamingContext context;

	context = root.new_context();

	//
	// Test exceptions
	//

	try
	{
	    //
	    // Try to bind a context when an intermediate context
	    // doesn't exist
	    //
	    name1 = new NameComponent[2];
	    name1[0] = new NameComponent("bad", "node");
	    name1[1] = new NameComponent("my", "node");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.missing_node)
		throw new RuntimeException();
	}

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("object", "");
	root.bind(name1, test);

	try
	{
	    //
	    // Try to bind a context when an object is in the path
	    //
	    name2 = new NameComponent[2];
	    name2[0] = new NameComponent("object", "");
	    name2[1] = new NameComponent("my", "node");
	    root.bind_context(name2, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.not_context)
		throw new RuntimeException();
	}

	try
	{
	    //
	    // Try to bind a context using the name of an existing object
	    //
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	root.unbind(name1);

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("context", "");
	root.bind_context(name1, context);

	try
	{
	    //
	    // Try to bind an object using the name of an existing context
	    //
	    root.bind(name1, test);

	    // bind should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	root.unbind(name1);

	try
	{
	    //
	    // Try to bind a context with an invalid name
	    //
	    name1 = new NameComponent[0];
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(InvalidName ex)
	{
	    // expected
	}

	try
	{
	    //
	    // Try to bind a context with an invalid name
	    //
	    name1 = new NameComponent[1];
	    name1[0] = new NameComponent("", "");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(InvalidName ex)
	{
	    // expected
	}

	//
	// Bind an intermediate context for use in more tests
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("ctx", "");
	root.bind_context(name1, context);

	try
	{
	    //
	    // Try to bind a context when an intermediate context
	    // doesn't exist
	    //
	    name1 = new NameComponent[3];
	    name1[0] = new NameComponent("ctx", "");
	    name1[1] = new NameComponent("bad", "node");
	    name1[2] = new NameComponent("my", "node");
	    root.bind_context(name1, context);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.missing_node)
		throw new RuntimeException();
	}

	NamingContext ctx = root.new_context();;

	name1 = new NameComponent[1];
	name1[0] = new NameComponent("object", "");
	context.bind(name1, test);

	try
	{
	    //
	    // Try to bind a context when an object is in the path
	    //
	    name2 = new NameComponent[3];
	    name2[0] = new NameComponent("ctx", "");
	    name2[1] = new NameComponent("object", "");
	    name2[2] = new NameComponent("my", "node");
	    root.bind_context(name2, ctx);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(NotFound ex)
	{
	    if(ex.why != NotFoundReason.not_context)
		throw new RuntimeException();
	}

	try
	{
	    //
	    // Try to bind a context to an existing name
	    //
	    name2 = new NameComponent[2];
	    name2[0] = new NameComponent("ctx", "");
	    name2[1] = new NameComponent("object", "");
	    root.bind_context(name2, ctx);

	    // bind_context should not have succeeded
	    throw new RuntimeException();
	}
	catch(AlreadyBound ex)
	{
	    // expected
	}

	context.unbind(name1);

	//
	// Clean up context
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("ctx", "");
	root.unbind(name1);

	//
	// Test name equality to make sure kind is included in comparisons
	//
	name1 = new NameComponent[1];
	name1[0] = new NameComponent("context", "kind1");
	name2 = new NameComponent[1];
	name2[0] = new NameComponent("context", "kind2");
	root.bind_context(name1, ctx);
	root.bind_context(name2, ctx);
	root.unbind(name1);
	root.unbind(name2);

	ctx.destroy();

	context.destroy();
    }
}
